yakumo.mapper.NoopClass

Package yakumo :: Module mapper :: Class NoopClass |
[hide private]
[frames] | no frames]

# Class NoopClass

source code

    object --+
             |
            NoopClass

Instance Methods | [hide private]
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Static Methods | [hide private]
to_attr(manager_class, attr, do_raise=False) | source code
to_json(manager_class, attr) | source code

Properties | [hide private]
Inherited from `object`: `__class__`